@@ -2,10 +2,12 @@ from .binary import BinaryDataTest
 from .normal import NormalDataTest
 from .delta_lognormal import DeltaLognormalDataTest
 from .discrete import DiscreteDataTest
+from .poisson import PoissonDataTest
 
 __all__ = [
     "BinaryDataTest",
     "NormalDataTest",
     "DeltaLognormalDataTest",
     "DiscreteDataTest",
+    "PoissonDataTest",
 ]
